==> kubernetes-model-1.0.47-sources.jar: io/fabric8/openshift/api/model/TLSConfigFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class TLSConfigFluentImpl<T extends TLSConfigFluent<T>> extends BaseFluent<T> implements TLSConfigFluent<T>{

     String caCertificate;     String certificate;     String destinationCACertificate;     String insecureEdgeTerminationPolicy;     String key;     String termination;     Map<String, Object> additionalProperties = new HashMap();
public TLSConfigFluentImpl(){
    
}
public TLSConfigFluentImpl( TLSConfig instance ){
    this.withCaCertificate(instance.getCaCertificate()); this.withCertificate(instance.getCertificate()); this.withDestinationCACertificate(instance.getDestinationCACertificate()); this.withInsecureEdgeTerminationPolicy(instance.getInsecureEdgeTerminationPolicy()); this.withKey(instance.getKey()); this.withTermination(instance.getTermination()); 
}

    public String getCaCertificate(){
    return this.caCertificate;
    }
    public T withCaCertificate( String caCertificate){
    this.caCertificate=caCertificate; return (T) this;
    }
    public String getCertificate(){
    return this.certificate;
    }
    public T withCertificate( String certificate){
    this.certificate=certificate; return (T) this;
    }
    public String getDestinationCACertificate(){
    return this.destinationCACertificate;
    }
    public T withDestinationCACertificate( String destinationCACertificate){
    this.destinationCACertificate=destinationCACertificate; return (T) this;
    }
    public String getInsecureEdgeTerminationPolicy(){
    return this.insecureEdgeTerminationPolicy;
    }
    public T withInsecureEdgeTerminationPolicy( String insecureEdgeTerminationPolicy){
    this.insecureEdgeTerminationPolicy=insecureEdgeTerminationPolicy; return (T) this;
    }
    public String getKey(){
    return this.key;
    }
    public T withKey( String key){
    this.key=key; return (T) this;
    }
    public String getTermination(){
    return this.termination;
    }
    public T withTermination( String termination){
    this.termination=termination; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
TLSConfigFluentImpl that = (TLSConfigFluentImpl) o;
if (caCertificate != null ? !caCertificate.equals(that.caCertificate) :that.caCertificate != null) return false;
if (certificate != null ? !certificate.equals(that.certificate) :that.certificate != null) return false;
if (destinationCACertificate != null ? !destinationCACertificate.equals(that.destinationCACertificate) :that.destinationCACertificate != null) return false;
if (insecureEdgeTerminationPolicy != null ? !insecureEdgeTerminationPolicy.equals(that.insecureEdgeTerminationPolicy) :that.insecureEdgeTerminationPolicy != null) return false;
if (key != null ? !key.equals(that.key) :that.key != null) return false;
if (termination != null ? !termination.equals(that.termination) :that.termination != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/openshift/api/model/TLSConfigFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class TLSConfigFluentImpl<A extends TLSConfigFluent<A>> extends BaseFluent<A> implements TLSConfigFluent<A>{

     String caCertificate;     String certificate;     String destinationCACertificate;     String insecureEdgeTerminationPolicy;     String key;     String termination;
public TLSConfigFluentImpl(){
    
}
public TLSConfigFluentImpl( TLSConfig instance ){
    this.withCaCertificate(instance.getCaCertificate()); this.withCertificate(instance.getCertificate()); this.withDestinationCACertificate(instance.getDestinationCACertificate()); this.withInsecureEdgeTerminationPolicy(instance.getInsecureEdgeTerminationPolicy()); this.withKey(instance.getKey()); this.withTermination(instance.getTermination()); 
}

    public String getCaCertificate(){
    return this.caCertificate;
    }
    public A withCaCertificate( String caCertificate){
    this.caCertificate=caCertificate; return (A) this;
    }
    public String getCertificate(){
    return this.certificate;
    }
    public A withCertificate( String certificate){
    this.certificate=certificate; return (A) this;
    }
    public String getDestinationCACertificate(){
    return this.destinationCACertificate;
    }
    public A withDestinationCACertificate( String destinationCACertificate){
    this.destinationCACertificate=destinationCACertificate; return (A) this;
    }
    public String getInsecureEdgeTerminationPolicy(){
    return this.insecureEdgeTerminationPolicy;
    }
    public A withInsecureEdgeTerminationPolicy( String insecureEdgeTerminationPolicy){
    this.insecureEdgeTerminationPolicy=insecureEdgeTerminationPolicy; return (A) this;
    }
    public String getKey(){
    return this.key;
    }
    public A withKey( String key){
    this.key=key; return (A) this;
    }
    public String getTermination(){
    return this.termination;
    }
    public A withTermination( String termination){
    this.termination=termination; return (A) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
TLSConfigFluentImpl that = (TLSConfigFluentImpl) o;
if (caCertificate != null ? !caCertificate.equals(that.caCertificate) :that.caCertificate != null) return false;
if (certificate != null ? !certificate.equals(that.certificate) :that.certificate != null) return false;
if (destinationCACertificate != null ? !destinationCACertificate.equals(that.destinationCACertificate) :that.destinationCACertificate != null) return false;
if (insecureEdgeTerminationPolicy != null ? !insecureEdgeTerminationPolicy.equals(that.insecureEdgeTerminationPolicy) :that.insecureEdgeTerminationPolicy != null) return false;
if (key != null ? !key.equals(that.key) :that.key != null) return false;
if (termination != null ? !termination.equals(that.termination) :that.termination != null) return false;
return true;

    }



}
